@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from .commands import *
 from .projects import *
 from .queues import *
@@ -7,13 +8,14 @@ from .utils import *
 from .version import *
 from .workers import *
 # Keep the linter happy
+from . import constants
 from . import defaults
 from . import projects
 from . import pyos_extensions
 from . import version
 from . import workers
 
-_ADDITIONAL = ('defaults',)
+_ADDITIONAL = 'defaults', 'constants'
 
 __all__ = (commands.__all__ + queues.__all__ + tasks.__all__ + utils.__all__ + version.__all__ +
            workers.__all__ + settings.__all__ + projects.__all__) + _ADDITIONAL
